% Rolf Niepraschk, Rolf.Niepraschk@ptb.de

\setcounter{errorcontextlines}{100}  \listfiles

\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{ptbposter}
    [2015/03/20 v0.2f PTB-Poster-Klasse (RN)]

\newdimen\PTB@topmargin      % Abstand zum Rahmen
\newdimen\PTB@leftmargin     % Abstand zum Rahmen
\newdimen\PTB@default@fsize@base  % Bezugsgröße für Standardschriftgröße im Textbereich
\newdimen\PTB@default@fsize  % Standardschriftgröße im Textbereich (\normalsize)
\newdimen\PTB@default@tfsize % Standardschriftgröße für den Titel
\newdimen\PTB@default@afsize % Standardschriftgröße für die Autoren
\newdimen\PTB@default@ffsize % Standardschriftgröße im Fußbereich
\newdimen\PTB@texthsep       % Abstand Textbereich zum blauen Rahmen
\newdimen\PTB@textvsep       % Abstand Textbereich zum blauen Rahmen
\newdimen\PTB@framewidth     % Breite des blauen Rahmens
\newdimen\PTB@frameheight    % Höhe des blauen Rahmens
\newdimen\PTB@scale@base    % Bezugsgröße für papierabhängige Größenberechnung

\newcommand*\authorFontSize{}
\newcommand*\footFontSize{}
\newcommand*\titleFontSize{}

\newcommand\PTB@tempa{}
\newcommand\PTB@tempb{}
\newcommand\PTB@tempc{}
\newcommand\PTB@tempd{}
\newcommand\PTB@tempe{}

\let\PTB@tempdima=\@ovxx
\let\PTB@tempdimb=\@ovyy
\let\PTB@tempdimc=\@ovdx

\newcounter{PTB@tempcnta}
\newcounter{PTB@tempcntb}

\newif\ifPTB@is@landscape \PTB@is@landscapefalse

\DeclareOption{sanserif}{% noch experimentell! Besser: luaTeX/xeTeX + OTF
  \AtEndOfClass{%
    \renewcommand\familydefault{\sfdefault}
    \RequirePackage{sfmath}
  }
}
\DeclareOption{serif}{%
  \AtEndOfClass{%
    \renewcommand\familydefault{\rmdefault}
  }
}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}

\ExecuteOptions{portrait,serif}
\ProcessOptions\relax

\RequirePackage{hyphsubst}% Trennregeln austauschen
\HyphSubstIfExists{ngerman-x-latest}{%
  \HyphSubstLet{ngerman}{ngerman-x-latest}}{}
\HyphSubstIfExists{german-x-latest}{%
  \HyphSubstLet{german}{german-x-latest}}{}

\RequirePackage{etoolbox}
\preto\@classoptionslist{a0paper,portrait,ngerman,}
% Ohne Sprachangabe "deutsch" verwenden. Bessere Lösung?

% TODO: Auf OTF-Fonts wechseln (XeLaTeX / LuaLaTeX)
\RequirePackage{textcomp}
\RequirePackage{lmodern}
\RequirePackage{tgpagella,qpxmath}
\RequirePackage{tgheros}

\LoadClass[%
%,parskip=half
%,fontsize=41pt
]{scrartcl}
% "fontsize=41pt" verhindert das Laden von "scrsize11pt.clo" o.ä.

\RequirePackage{geometry}% Papiergröße steht fest (Standard: A0)

\ifdim\paperheight>\paperwidth
  \setlength\PTB@scale@base{\paperheight}
  \PTB@is@landscapefalse
\else
  \setlength\PTB@scale@base{\paperwidth}
  \PTB@is@landscapetrue
\fi

\setlength\PTB@default@fsize@base{0.0130170299199\PTB@scale@base}%  11pt bei A4
\setlength\PTB@default@afsize{0.0157550946737\PTB@scale@base}% 53.3pt bei A0
\setlength\PTB@default@tfsize{0.0315101893474\PTB@scale@base}% 106.6pt bei A0
\setlength\PTB@default@ffsize{0.00567538119577\PTB@scale@base}% 19.2pt bei A0
\setlength\PTB@topmargin{0.180824222418\PTB@scale@base}% 612pt (215mm) bei A0

\newcommand*\scaleFontSizes[1]{%
  \PTB@default@fsize=#1\PTB@default@fsize@base
}

\newcommand*\scaleTitleFontSize[1]{%
  \PTB@tempdima=\PTB@default@tfsize
  \PTB@tempdima=#1\PTB@tempdima
  \PTB@tempdimb=1.2\PTB@tempdima
  \xdef\titleFontSize{\noexpand\@setfontsize
    \noexpand\titleFontSize{\the\PTB@tempdima}{\the\PTB@tempdimb}}%
}

\scaleFontSizes{1}% wird ggf. in Präambel noch mal angepasst
\scaleTitleFontSize{1}% wird ggf. in Präambel noch mal angepasst

\edef\authorFontSize{\noexpand\@setfontsize\noexpand\authorFontSize{%
  \the\PTB@default@afsize}{\the\dimexpr1.2\PTB@default@afsize}}
\edef\footFontSize{\noexpand\@setfontsize\noexpand\footFontSize{%
  \the\PTB@default@ffsize}{\the\dimexpr1.2\PTB@default@ffsize}}

\RequirePackage[svgnames]{xcolor}
\RequirePackage[newcommands,newparameters]{ragged2e}% ???
\RequirePackage{multicol,graphicx}
\RequirePackage[%
,factor=1500
,protrusion=true
,expansion=true
,verbose=true
,final=true
,letterspace=100
,babel=true
]{microtype}

\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}

\RequirePackage{babel}

\AtEndOfClass{%
  \shorthandon{"}%
  \@tempswafalse
  \iflanguage{ngerman}{\@tempswatrue}{%
    \iflanguage{german}{\@tempswatrue}{}%
  }
  \if@tempswa
    \defineshorthand{"`}{\guillemotright}%
    \defineshorthand{"'}{\guillemotleft}%
  \fi
  \RequirePackage[final,pdfpagelabels=false,%
    plainpages=false,hypertexnames=true,hyperfootnotes=false]{hyperref}%
}

\RequirePackage
  [autostyle=true,babel=once,german=guillemets,maxlevel=3]{csquotes}%

\newcommand*\PTB@qrcode{}
\newcommand*\QRcode[1]{\gdef\PTB@qrcode{#1}}
\newcommand*\PTB@location{38116~Braunschweig}
\newcommand*\location[1]{\gdef\PTB@location{#1}}
\newcommand*\PTB@street{Bundesallee~100}
\newcommand*\street[1]{\gdef\PTB@street{#1}}
\newcommand*\PTB@workingGroup{Arbeitsgruppe}
\newcommand*\workingGroup[1]{\gdef\PTB@workingGroup{#1}}
\newcommand*\PTB@department{Fachbereich}
\newcommand*\department[1]{\gdef\PTB@department{#1}}
\newcommand*\PTB@phone{}
\newcommand*\phone[1]{\gdef\PTB@phone{#1}}
\newcommand*\PTB@email{}
\newcommand*\email[1]{\gdef\PTB@email{#1}}
\newcommand*\PTB@fax{}
\newcommand*\fax[1]{\gdef\PTB@fax{#1}}
\newcommand*\PTB@final@paper{}
\newcommand*\scaletoPaper[1]{\gdef\PTB@final@paper{#1}}

\definecolor{PTBcolor}{rgb}{0,0.67451,0.87451}

\RequirePackage[texcoord]{eso-pic}
\RequirePackage{pict2e,picture,ifdraft,booktabs}
\RequirePackage{qrcode}

\AddToShipoutPictureBG*{% Kopf (relativ zur oberen Blattkante)
  \PTB@tempdima=-0.08023549218\PTB@scale@base
  \put(\PTB@leftmargin,\PTB@tempdima){%
    \includegraphics[width=.401\PTB@scale@base]{ptbposter-logo.pdf}}%
  \PTB@tempdima=-0.134566863195\PTB@scale@base
  \put(\PTB@leftmargin,\PTB@tempdima){\sffamily\titleFontSize\@title}%
  \PTB@tempdima=-0.159798150044\PTB@scale@base
  \def\and{, }%
  \put(\PTB@leftmargin,\PTB@tempdima){\sffamily\authorFontSize\@author}%
  % hier wird \@thanks gefüllt
  \PTB@tempdima=0.00168208578994\PTB@scale@base
  \linethickness{\PTB@tempdima}\color{PTBcolor}
  \PTB@tempdima=-0.0883095039717\PTB@scale@base
  \put(\PTB@leftmargin,\PTB@tempdima){%
    \line(1,0){\dimexpr\paperwidth-2\PTB@leftmargin}}%
  \put(\PTB@leftmargin,\dimexpr-\textheight-2\PTB@textvsep-\PTB@topmargin)%
    {\framebox(\dimexpr\textwidth+2\PTB@texthsep,%
     \dimexpr\textheight+2\PTB@textvsep){}}%
}

\AddToShipoutPictureBG*{% Fuß (relativ zur unteren Kante des Textbereichs)
  \AtTextLowerLeft{%
    \put(-\PTB@texthsep,-\PTB@textvsep){%
      \PTB@tempdimb=0.000420521447484\PTB@scale@base
      \linethickness{\PTB@tempdimb}\normalcolor
      \PTB@tempdima=-0.0420521447484\PTB@scale@base
      \put(-.5\@wholewidth,\PTB@tempdima){%
        \PTB@tempdima=0.0386879731686\PTB@scale@base
        \PTB@tempdimb=0.00168208578994\PTB@scale@base
        \ifx\PTB@qrcode\@empty
          \color{PTBcolor}\framebox(\PTB@tempdima,\PTB@tempdima){}%
        \else
          \raisebox{0.71\height}{%
            \qrcode[height=\PTB@tempdima,tight]{\PTB@qrcode}}%
        \fi
        \color{PTBcolor}
        \hspace{\PTB@tempdimb}\raisebox{-\@wholewidth}{%
          \rule{\dimexpr\PTB@tempdima+2\@wholewidth}%
            {\dimexpr\PTB@tempdima+2\@wholewidth}}%
        \hspace{\PTB@tempdimb}\framebox(\PTB@tempdima,\PTB@tempdima){}%
      }
      \PTB@tempdimb=-0.00841042894969\PTB@scale@base
      \footFontSize\sffamily\normalcolor
      \PTB@tempdima=0.122792262665\PTB@scale@base
      \put(\PTB@tempdima,\PTB@tempdimb){%
        \begin{tabular}[t]{@{}l@{}}
          Physikalisch-Technische Bundesanstalt \\
          Braunschweig und Berlin \\[\f@baselineskip]
          \ifx\first@author\@empty\else \textbf{\first@author}\\\fi
          \ifx\PTB@department\@empty\else \PTB@department\\\fi
          \ifx\PTB@workingGroup\@empty\else \PTB@workingGroup\\\fi
        \end{tabular}%
      }
      \PTB@tempdima=0.263246426125\PTB@scale@base
      \put(\PTB@tempdima,\PTB@tempdimb){%
        \begin{tabular}[t]{@{}ll@{}}
          \ifx\PTB@street\@empty\else\multicolumn{2}{@{}l@{}}{\PTB@street}\\\fi
          \ifx\PTB@location\@empty\else\multicolumn{2}{@{}l@{}}{\PTB@location}\\\fi
          \ifx\PTB@phone\@empty\else Telefon:&\PTB@phone\\\fi
          \ifx\PTB@fax\@empty\else Fax:&\PTB@fax\\\fi
          \ifx\PTB@email\@empty\else E-Mail:&\href{mailto:\PTB@email}{\PTB@email}\\\fi
          \multicolumn{2}{@{}l@{}}{\href{http://www.ptb.de/}{www.ptb.de}}
        \end{tabular}%
      }
      \PTB@tempdima=0.378469302736\PTB@scale@base
      \put(\PTB@tempdima,\PTB@tempdimb){%
        \begin{tabular}[t]{@{}l@{}}
          \@thanks % wurde bei der Ausführung von \@author gefüllt.
        \end{tabular}%
      }
    }
  }
}

% ===== Behandlung der Autoren (siehe ptb-abstracts.sty ) =====

\newcommand*\first@author{}
\def\author#1{}
\def\@author{}

\renewcommand\footnotetext[2][]{%
  \textsuperscript{#1}\,#2\\
}

\newcommand\PTB@dec@footnotemark[1][]{%
  \addtocounter{footnote}{-1}%
  \begingroup
    \edef\PTB@tempa{#1}%
    \ifx\PTB@tempa\@empty\footnotemark\else\footnotemark[#1]\fi
  \endgroup
}

\newcommand\PTB@fnmark[1]{%
  \begingroup
    \unrestored@protected@xdef\@thefnmark{#1}%
  \endgroup
  %\show\@thefnmark
  \@footnotemark}

\newcommand\Author{%
  \begingroup
    \@ifstar{\@tempswatrue\@Author}{\@tempswafalse\@Author}}

\newcommand\@Author[2][]{%     \PTB@tempa=[footnotemark],\PTB@tempb={Firstname}
  \def\PTB@tempa{#1}\def\PTB@tempb{#2}%
  \@@Author}

\newcommand\@@Author[2][]{%    \PTB@tempc=[alt. Firstname],\PTB@tempd={Surname}
  \def\PTB@tempc{#1}\def\PTB@tempd{#2}%
  \@@@Author}

\newcommand\@@@Author[1][]{%   \PTB@tempe=[Address]
    \def\PTB@tempe{#1}%
    \ifx\PTB@tempd\@empty
      % Empty Surname = Addition to the previous author
      \g@addto@macro\@author{\PTB@fnmark{,}}%
    \else
      \ifx\@author\@empty
        \xdef\@author{\PTB@tempb~\PTB@tempd}%
        \xdef\first@author{\PTB@tempb~\PTB@tempd}%
      \else
        \expandafter\g@addto@macro\expandafter\@author
          \expandafter{\expandafter\and\PTB@tempb~}%
        \expandafter\g@addto@macro\expandafter\@author
          \expandafter{\PTB@tempd}% I like it ;-(
      \fi
    \fi
    \if@tempswa
      %                --> \Author*
      \g@addto@macro\@author{\PTB@dec@footnotemark}%
    \fi
    \ifx\PTB@tempa\@empty\else
      \expandafter\g@addto@macro\expandafter\@author
        \expandafter{\expandafter\PTB@fnmark\expandafter{\PTB@tempa}}%
    \fi
    \ifx\PTB@tempe\@empty\else
      \if@tempswa
        \g@addto@macro\@author{\PTB@fnmark{,}}%
      \fi
      \expandafter\g@addto@macro\expandafter\@author
        \expandafter{\expandafter\thanks\expandafter{\PTB@tempe}}%
    \fi
  \endgroup
}

\let\PTB@thanks\thanks
\renewcommand\thanks[2][]{%
  \begingroup
    \def\PTB@tempa{#2}%
    \ifx\PTB@tempa\@empty
      \footnotemark[\value{footnote}]%
    \else
      \PTB@thanks{#2}%
    \fi
  \endgroup
}%

\renewcommand*\labelitemi{$\m@th\circ$}
\renewcommand*\labelitemii{$\m@th\triangleright$}
\renewcommand*\labelitemiii{$\m@th\diamond$}
%\renewcommand*\labelitemiv{\makebox[.5em]{\scalebox{1.5}{\textbullet}}}%
\renewcommand*\labelitemiv{\textbullet}%

\newcommand*\PTB@scaletoPaper[1]{%
  \begingroup
    \c@PTB@tempcnta=\paperheight
    \iso@paper{#1}%
    \c@PTB@tempcntb=\paperheight
    \PTB@tempdimc=\dimexpr \c@PTB@tempcntb sp * 1000 / \c@PTB@tempcnta %
    \c@PTB@tempcntb=\PTB@tempdimc %
    \global\mag\c@PTB@tempcntb
  \endgroup
}


\AtBeginDocument{%
  % Skalierungen in der Präambel sind passiert.
  %%%\makeatletter\input{ptbposter-size.clo}\makeatother{}
  \changefontsizes{\the\PTB@default@fsize}%
  \setlength\PTB@texthsep{.5em}%
  \setlength\PTB@textvsep{.75em}%
  \ifPTB@is@landscape
    \setlength\PTB@framewidth{0.950378471315\PTB@scale@base}%  3215pt (1130mm) bei A0
    \setlength\PTB@frameheight{0.462573592233\PTB@scale@base}% 1565pt  (550mm) bei A0
  \else
    \setlength\PTB@framewidth{0.656013458076\PTB@scale@base}%  2219pt  (780mm) bei A0
    \setlength\PTB@frameheight{0.740117747573\PTB@scale@base}% 2504pt  (880mm) bei A0
  \fi
  \setlength\PTB@leftmargin{0.5\dimexpr\paperwidth-\PTB@framewidth}%
  \edef\PTB@tempa{\noexpand\newgeometry{%
      columnsep=2em,hcentering,%
      top=\the\dimexpr\PTB@topmargin+\PTB@textvsep,%
      textwidth=\the\dimexpr\PTB@framewidth-2\PTB@texthsep,%
      textheight=\the\dimexpr\PTB@frameheight-2\PTB@textvsep
    }%
  }%
  \PTB@tempa\normalsize
  \ifx\PTB@final@paper\@empty\else\PTB@scaletoPaper{\PTB@final@paper}\fi
  \KOMAoptions{parskip=half}
  \setlength\leftmargini{1.5em}
  \setlength\leftmarginii{1.4em}
  \setlength\leftmarginiii{1.3em}
  \setlength\leftmarginiv{1.2em}
  \renewcommand\section{\@startsection{section}{1}{\z@}%
    {-1.5ex \@plus -.5ex \@minus -.2ex}%
    {.8ex \@plus .2ex}%
    {\raggedsection\normalfont\sectfont\size@section}%
  }
  \setlength\emergencystretch{3em}%
  \@ifpackageloaded{multicol}{%
    \def\setemergencystretch#1#2{\setlength\emergencystretch{3em}}%
  }{}%
}

\setcounter{secnumdepth}{-2}
\renewcommand*\maketitle[1][1]{}
\renewcommand*\tableofcontents{}
\pagestyle{empty}

\endinput
